@@ -3,14 +3,13 @@
  *
  * Author:  Kazu Yamamoto <Kazu@Mew.org>
  * Created: Dec  8, 1994
- * Revised: Jul 10, 2001
  *
  * Code:
  */
 
 #include "mew.h"
 
-private char version_message[] = "version 3.3 20030522 Kazu Yamamoto";
+private char version_message[] = "version 5.3 20060727 Kazu Yamamoto";
 
 #ifdef HAVE_UNISTD_H
 #include <sys/types.h>
@@ -244,7 +243,7 @@ deflate_gzip(byte *p, unsigned int max)
 		err = deflateInit2(&z, Z_DEFAULT_COMPRESSION,
 				   Z_DEFLATED, -MAX_WBITS,
 				   8, Z_DEFAULT_STRATEGY);
-		if (err != Z_OK) warn_exit("deflateInit2 error.\n");
+		if (err != Z_OK) warn_exit("deflateInit2 error.");
 		*p++ = 0x1f;
 		*p++ = 0x8b;
 		*p++ = Z_DEFLATED;
@@ -281,7 +280,7 @@ deflate_gzip(byte *p, unsigned int max)
 		err = deflate(&z, Z_SYNC_FLUSH);
 
 		if (err != Z_OK && err != Z_STREAM_END)
-			warn_exit("inflate error (%d).\n", err);
+			warn_exit("inflate error (%d).", err);
 
 		deflated = max - z.avail_out;		
 
@@ -298,7 +297,7 @@ deflate_gzip(byte *p, unsigned int max)
 	} while (err != Z_STREAM_END);
 		
 	if (deflateEnd(&z) != Z_OK)
-		warn_exit("deflateEnd error.\n");
+		warn_exit("deflateEnd error.");
 
 	deflated = max - z.avail_out;
 	q = z.next_out;
@@ -437,7 +436,7 @@ gzip64_encode(int text, int length)
 	E_ctx.e_length = length;
 	write_base64();
 #else /* HAVE_LIBZ */
-	warn_exit("not linked to zlib.\n");
+	warn_exit("not linked to zlib.");
 #endif /* HAVE_FORK */
 }
 
@@ -496,7 +495,7 @@ read_base64(byte *p, unsigned int max)
 		d = base256[c];
 		switch (d) {
 		case OOB:
-			warning("illegal base64 character.\n");
+			warning("invalid base64 character.");
 			goto skiptail;
 		case EOP:
 			goto skiptail;
@@ -546,7 +545,7 @@ decode_base64(byte *p, unsigned int max)
 				case 0:
 					return out;
 				case 1:
-					warning("illegal base64 length.\n");
+					warning("invalid base64 length.");
 					return out; /* anyway */
 				case 2:
 					c1 = *q++;
@@ -601,13 +600,13 @@ inflate_gzip(byte *p, unsigned int max)
 		z.zfree = (free_func)0;
 		z.opaque = (voidpf)0;
 		err = inflateInit2(&z, -MAX_WBITS);
-		if (err != Z_OK) warn_exit("inflateInit2 error.\n");
+		if (err != Z_OK) warn_exit("inflateInit2 error.");
 		size = (*D_ctx.d_func2)(d_buf2, sizeof(d_buf2));
 		q = d_buf2;
 		r = q + size;
-		if (*q++ != 0x1f) warn_exit("not gzip format (ID1).\n");
-		if (*q++ != 0x8b) warn_exit("not gzip format (ID2).\n");
-		if (*q++ != Z_DEFLATED) warn_exit("not gzip format (CM).\n");
+		if (*q++ != 0x1f) warn_exit("not gzip format (ID1).");
+		if (*q++ != 0x8b) warn_exit("not gzip format (ID2).");
+		if (*q++ != Z_DEFLATED) warn_exit("not gzip format (CM).");
 		flag = *q++;
 		q += 6; /* mtime, xf, os */
 
@@ -646,7 +645,7 @@ inflate_gzip(byte *p, unsigned int max)
 		err = inflate(&z, Z_SYNC_FLUSH);
 
 		if (err != Z_OK && err != Z_STREAM_END)
-			warn_exit("inflate error (%d).\n", err);
+			warn_exit("inflate error (%d).", err);
 
 		inflated = max - z.avail_out;		
 
@@ -657,7 +656,7 @@ inflate_gzip(byte *p, unsigned int max)
 			done = YES;
 			/* 8 bytes (crc and isize) are left. */
 			if (inflateEnd(&z) != Z_OK)
-				warn_exit("inflateEnd error.\n");
+				warn_exit("inflateEnd error.");
 			break;
 		}
 	}
@@ -736,7 +735,7 @@ gzip64_decode(int text)
 	else
 		write_binary();
 #else /* HAVE_LIBZ */
-	warn_exit("not linked to zlib.\n");
+	warn_exit("not linked to zlib.");
 #endif /* HAVE_LIBZ */
 }
 /****************************************************************
@@ -851,7 +850,7 @@ puthexchar(int c1, int c2)
 		return(TRUE);
 	} else {
 		if (warned == NO) { /* warn just once */
-			warning("can't translate hex to character: %c%c\n", c1, c2);
+			warning("can't translate hex to character: %c%c", c1, c2);
 			warned = YES;
 		}
 		return(FALSE);	
@@ -870,18 +869,28 @@ quoted_printable_decode()
 		if (c1 == EQ) {
 			if ((c2 = getchar()) == EOF) {
 				putchar(EQ);
-				warn_exit("end of file after =.\n");
+				warn_exit("end of file after =.");
 			}
 			if (c2 == LF) continue;
+			if (c2 == CR) {
+				if ((c3 = getchar()) == EOF) break;
+				if (c3 == LF) {
+					continue;
+				} else {
+					ungetc(c3, stdin);
+					continue;
+				}
+
+			}
 			if ((c3 = getchar()) == EOF) {
 				putchar(EQ);
 				putchar(c2);
-				warn_exit("end of file after =.\n");
+				warn_exit("end of file after =.");
 			}
 			if (puthexchar(c2, c3) == FALSE) {
 				putchar(EQ);
 				if ((c1 = c2) == EOF)
-					warn_exit("illegal eof.\n");
+					warn_exit("invalid eof.");
 				ungetc(c3, stdin);
 				goto skipgetc;
 			} else
@@ -912,12 +921,12 @@ uu_decode(int use_file_name)
 		if (STRCMP(Uu_read_buf, "begin ") == 0) {
 			if (use_file_name == YES) {
 				if ((p = strchr(Uu_read_buf + 6, SP)) == NULL)
-					warn_exit("no filename for uudecode.\n");
+					warn_exit("no filename for uudecode.");
 				p++;
 				for (q = Uu_flnm_buf; *p != LF; p++, q++)
 					*q = *p;
 				if (freopen(Uu_flnm_buf, FDWRITE, stdout) == NULL)
-					warn_exit("can't open a file.\n");
+					warn_exit("can't open a file.");
 			}
 			break;
 		}
@@ -1049,14 +1058,14 @@ main(int argc, char **argv)
 
 	file_count = argc - Optind;
 
-	/* Override argments by progname. */
+	/* Override arguments by progname. */
 
 	if (action == ENCODE) {
 		if (STRCMP(progname, DECODE_NAME) == 0)
 			action = DECODE;
 		if (STRCMP(progname, CAT_NAME) == 0) {
 			if (file_count != 0)
-				warn_exit("too many argments.\n");
+				warn_exit("too many arguments.");
 			action = DECODE;
 		}
 	}
@@ -1068,20 +1077,20 @@ main(int argc, char **argv)
 		if (STRCMP(argv[Optind], "-") == 0)
 			;
 		else if (freopen(argv[Optind], FDREAD, stdin) == NULL)
-			warn_exit("can't open file %s.\n", argv[Optind]);
+			warn_exit("can't open file %s.", argv[Optind]);
 		break;
 	case 2:
 		if (STRCMP(argv[Optind], "-") == 0)
 			;
 		else if (freopen(argv[Optind], FDREAD, stdin) == NULL)
-			warn_exit("can't open file %s.\n", argv[Optind]);
+			warn_exit("can't open file %s.", argv[Optind]);
 		Optind++;
 		if (STRCMP(argv[Optind], "-") == 0)
 			;
 		else if (encode == UU)
 			use_file_name = YES;
 		else if (freopen(argv[Optind], FDWRITE, stdout) == NULL)
-			warn_exit("can't open file %s.\n", argv[Optind]);
+			warn_exit("can't open file %s.", argv[Optind]);
 		break;
 	default:
 		usage(progname);
@@ -1133,7 +1142,7 @@ main(int argc, char **argv)
 }
 
 /* 
- * Copyright (C) 1994-2003 Mew developing team.
+ * Copyright (C) 1994-2005 Mew developing team.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
