@@ -9,7 +9,7 @@
 
 #include "mew.h"
 
-private char version_message[] = "version 5.2 20060727 Kazu Yamamoto";
+private char version_message[] = "version 5.3 20060727 Kazu Yamamoto";
 
 #ifdef HAVE_UNISTD_H
 # include <sys/types.h>
@@ -62,6 +62,7 @@ private char version_message[] = "version 5.2 20060727 Kazu Yamamoto";
 #define INBOX    "+inbox"
 #define STDINFILE "-"
 #define HEAD     "head"
+#define FILE_SEPARATOR '\7'
 
 /* 16k, my experience says that 8k is not enough. */
 #define MAX_HEADER         16384
@@ -110,6 +111,9 @@ private int Body_len = MAX_BODY_LEN;
 private int PrintNumOfMsg = NO;
 private int Suffix_len = 0;
 
+private int no_fld_flag = 0;
+private int default_fld_error_flag = 0;
+
 /****************************************************************
  *
  * prototype
@@ -206,8 +210,7 @@ version(const char *progname) {
  */
 
 private void
-ch_home()
-{
+ch_home() {
 	char *home = getenv("HOME");
 #ifdef HAVE_GETPWUID
 	if(home == NULL || home[0] == NUL) {
@@ -224,8 +227,7 @@ ch_home()
 }
 
 private void
-ch_mail_home(char *dir)
-{
+ch_mail_home(char *dir) {
 	char *p = dir + 1, c;
 
 	if (dir == NULL) warn_exit("%s not exist.", dir);
@@ -255,16 +257,19 @@ ch_mail_home(char *dir)
 }
 
 private void
-ch_folder(char *folder)
-{
+ch_folder(char *folder) {
 	char c = *folder, *p = folder + 1;
 	switch (c) {
 	case '+':
 		ch_mail_home(Mail_home);
 		if (p == NUL)
 			break;
-		if (chdir(p) != 0)
-			warn_exit("can't change folder to %s.", folder);
+		if (chdir(p) != 0) {
+			if( no_fld_flag != 0 )
+				default_fld_error_flag = 1;
+			else
+				warn_exit("can't change folder to %s.", folder);
+		}
 		break;
 	case '~':
 		ch_home();
@@ -377,8 +382,7 @@ private unsigned int Scan_ctx_ptr_size;
 private unsigned int Scan_ctx_fld_num;
 
 private void
-init_fields(char *fields)
-{
+init_fields(char *fields) {
 	unsigned int i;
 	char *start, *p;
 
@@ -413,8 +417,7 @@ init_fields(char *fields)
 }
 
 private void
-print_field(char *buf, int lim, char *fname, char *fld)
-{
+print_field(char *buf, int lim, char *fname, char *fld) {
 	unsigned int i;
 	int match;
 	char *p, *q, *limp, *end, *prev, *body_beg = NULL;
@@ -530,8 +533,7 @@ init_search(char *buf, int lim) {
 }
 
 private char *
-mystrcasechr(char *s, int c)
-{
+mystrcasechr(char *s, int c) {
 	int lc = tolower(c);
 	int uc = toupper(c);
 	
@@ -543,8 +545,7 @@ mystrcasechr(char *s, int c)
 }
 
 private char *
-mystrcasestr(char *s1, char *s2)
-{
+mystrcasestr(char *s1, char *s2) {
 	char *p;
 	unsigned int len = strlen(s2);
 
@@ -768,8 +769,7 @@ scan_folder(struct fld_rng *fr) {
 }
 
 private void
-scan_init(unsigned int folders)
-{
+scan_init(unsigned int folders) {
 	Scan_ctx_folders = folders;
 	Scan_ctx_messages = 0;
 	Scan_ctx_buf_size = NUMBER_OF_FILE;
@@ -777,8 +777,7 @@ scan_init(unsigned int folders)
 }
 
 private FILE *
-scan_getfile(char **filename, char **foldername)
-{
+scan_getfile(char **filename, char **foldername) {
 	static unsigned int i = 0, j = 0;
 	FILE *fp;
 
@@ -825,8 +824,7 @@ scan_getfile(char **filename, char **foldername)
 
 #ifdef HAVE_FORK
 private void
-exec_init(unsigned int num) /* num == 0 */
-{
+exec_init(unsigned int num) { /* num == 0 */
 	int childpid;
 	int pipes[2];
 
@@ -872,8 +870,7 @@ exec_init(unsigned int num) /* num == 0 */
 }
 #else  /* HAVE_FORK */
 private void
-exec_init(unsigned int num) /* num == 0 */
-{
+exec_init(unsigned int num) { /* num == 0 */
 	if (strlen(Folders[0].folder) >= sizeof(Current_folder))
 		warn_exit("folder name is too long.");
 	STRCPY(Current_folder, Folders[0].folder);
@@ -882,8 +879,7 @@ exec_init(unsigned int num) /* num == 0 */
 #endif /* HAVE_FORK */
 
 private FILE *
-exec_getfile(char **filename, char **foldername)
-{
+exec_getfile(char **filename, char **foldername) {
 	FILE *fp;
 	char *p, *q, *r;
 	int c;
@@ -897,6 +893,8 @@ exec_getfile(char **filename, char **foldername)
 			while ((c = getchar()) != LF && c != EOF) ;
 		}
 		if (STRCMP(p, CHDIR) == 0) {
+			no_fld_flag = 0;
+			default_fld_error_flag = 0;
 			p = p + strlen(CHDIR);
 			while (*p == SP || *p == TAB) p++;
 			if (strlen(p) >= sizeof(Current_folder))
@@ -906,6 +904,8 @@ exec_getfile(char **filename, char **foldername)
 			*foldername = Current_folder;
 			continue;
 		}
+		if(default_fld_error_flag != 0)
+			warn_exit("default folder is not exist.");
 		while (*p == SP || *p == TAB) p++;
 		if (isdigit((unsigned char)*p) == 0) continue;
 		*filename = p;
@@ -937,8 +937,7 @@ exec_getfile(char **filename, char **foldername)
  */
 
 private void
-stdin_init(unsigned int num) /* num == 0 */
-{
+stdin_init(unsigned int num) { /* num == 0 */
 	if (strcmp(Input_file, STDINFILE) != 0)
 		if (freopen(Input_file, FDREAD, stdin) == NULL)
 			warn_exit("can't open %s.", Input_file);
@@ -956,10 +955,10 @@ stdin_init(unsigned int num) /* num == 0 */
  */
 
 private void
-set_fld_rng(struct fld_rng *fr, char *arg1, char *arg2)
-{
+set_fld_rng(struct fld_rng *fr, char *arg1, char *arg2) {
 	char *folder = arg1;
 	char *range = NULL, *last = NULL;
+	char *p;
 
 	if (arg1 != NULL) range = strchr(arg1, SP);
 	if (range == NULL)
@@ -984,6 +983,7 @@ set_fld_rng(struct fld_rng *fr, char *arg1, char *arg2)
 
 	if (folder == NULL) folder = INBOX;
 	STRDUP(fr->folder, folder);
+	while ((p = strchr(fr->folder, FILE_SEPARATOR)) != NULL) *p = SP;
 }
 
 /****************************************************************
@@ -993,8 +993,7 @@ set_fld_rng(struct fld_rng *fr, char *arg1, char *arg2)
  */
 
 int
-main(int argc, char **argv)
-{
+main(int argc, char **argv) {
 	int optc, rest;
 	int eflag = 0, nflag = 1, sflag = 0, wflag = 0;
 	int wait;
@@ -1087,6 +1086,7 @@ main(int argc, char **argv)
 		switch (rest) { /* lim == 0 */
 		case 0:
 			set_fld_rng(&Folders[lim++], NULL, NULL);
+			no_fld_flag = 1;
 			break;
 		case 1:
 			set_fld_rng(&Folders[lim++], argv[Optind], NULL);
