@@ -33,12 +33,9 @@
 
 (defun mew-scan-setup ()
   "Define functions (MEW-FOO) according 'mew-scan-fields-alias'."
-  (let ((n (length mew-scan-fields-alias))
-	(i 0))
-    (while (< i n)
-      (fset (intern (concat "MEW-" (nth i mew-scan-fields-alias)))
-	    `(lambda () (aref mew-vec ,i)))
-      (setq i (1+ i)))))
+  (dotimes (i (length mew-scan-fields-alias))
+    (fset (intern (concat "MEW-" (nth i mew-scan-fields-alias)))
+	  `(lambda () (aref mew-vec ,i)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -81,10 +78,9 @@ effect to this function."
 	     (cc (mew-addrstr-parse-address-list (MEW-CC))))
 	(setq to (nconc to cc))
 	(catch 'loop
-	  (while to
-	    (if (mew-is-my-address mew-regex-my-address-list (car to))
-		(throw 'loop (setq review t)))
-	    (setq to (cdr to))))))
+	  (dolist (cto to)
+	    (if (mew-is-my-address mew-regex-my-address-list cto)
+		(throw 'loop (setq review t)))))))
     (cond
      (duplicated (char-to-string mark-delete))
      (spam       (char-to-string mark-spam))
@@ -92,24 +88,38 @@ effect to this function."
      (unread     (char-to-string mew-mark-unread))
      (t          (char-to-string mew-mark-read)))))
 
+(defvar mew-type-mark-invalid     "#")
+(defvar mew-type-mark-truncated   "T")
+(defvar mew-type-mark-signed      "S")
+(defvar mew-type-mark-encrypted   "E")
+(defvar mew-type-mark-multipart   "M")
+(defvar mew-type-mark-alternative "-")
+(defvar mew-type-mark-partial     "P")
+(defvar mew-type-mark-nothing     " ")
+
 (defun mew-summary-form-type ()
   "A function to return a mark of content type."
   (let ((ct (MEW-CT))
 	(case-fold-search t))
     (cond
-     ((mew-scan-message-invalidp)         "#")
-     ((mew-scan-message-truncatedp)       "T")
-     ((string-match mew-ct-mls  ct)       "S")
-     ((string-match mew-ct-mle  ct)       "E")
-     ((string-match mew-ct-sms  ct)       "E")
-     ((string-match mew-ct-xsms ct)       "E")
-     ((or (string-match mew-ct-smm ct) (string-match mew-ct-xsmm ct))
+     ((mew-scan-message-invalidp)         mew-type-mark-invalid)
+     ((mew-scan-message-truncatedp)       mew-type-mark-truncated)
+     ((string-match mew-ct-mls  ct)       mew-type-mark-signed)
+     ((string-match mew-ct-mle  ct)       mew-type-mark-encrypted)
+     ((string-match mew-ct-sms  ct)       mew-type-mark-encrypted)
+     ((string-match mew-ct-xsms ct)       mew-type-mark-encrypted)
+     ((or (string-match mew-ct-smm ct)
+	  (string-match mew-ct-xsmm ct))
+      ;; checking smime-type
       (cond
-       ((string-match mew-ct-smm-sig ct)  "S")
-       ((string-match mew-ct-smm-enc ct)  "E")))
-     ((mew-ct-multipartp ct)              "M")
-     ((string-match "Message/Partial" ct) "P")
-     (t " "))))
+       ((string-match mew-ct-smm-sig ct)  mew-type-mark-signed)
+       ((string-match mew-ct-smm-enc ct)  mew-type-mark-encrypted)
+       ;; smime-type is optional, sigh
+       (t                                 mew-type-mark-encrypted)))
+     ((mew-ct-alternativep ct)            mew-type-mark-alternative)
+     ((mew-ct-multipartp ct)              mew-type-mark-multipart)
+     ((mew-ct-partialp ct)                mew-type-mark-partial)
+     (t                                   mew-type-mark-nothing))))
 
 (defun mew-summary-form-time ()
   "A function to return a message time, HH:MM"
@@ -184,11 +194,9 @@ with -4. See also 'mew-summary-form-size-0k' and 'mew-summary-form-size-huge'."
 		       (mew-addrbook-func mew-addrbook-for-summary)))
 	     (raw (or (mew-addrstr-parse-address addr) ""))
 	     (rules mew-summary-form-extract-rule)
-	     rule ret nickname)
+	     ret nickname)
 	(catch 'matched
-	  (while rules
-	    (setq rule (car rules))
-	    (setq rules (cdr rules))
+	  (dolist (rule rules)
 	    (cond
 	     ((and (eq rule 'name)
 		   (or (string-match "^\"\\([^\"]+\\)\"[ \t]*<[^>]+>" addr)
@@ -215,7 +223,7 @@ with -4. See also 'mew-summary-form-size-0k' and 'mew-summary-form-size-huge'."
   "A function to return an address.
 If the message is destined to me AND 'mew-summary-form-from-me-prefix'
 is a string, an address on To:, is returned. In this
-case, 'mew-summary-form-from-me-prefix' is prepended to the address. 
+case, 'mew-summary-form-from-me-prefix' is prepended to the address.
 
 Otherwise, an address on From: is returned.
 
@@ -253,40 +261,39 @@ Address is converted by 'mew-summary-form-extract-addr'. See also
 ;;; Scan from
 ;;;
 
-(defun mew-get-summary-form (folder &optional column)
-  "Get summary-form from 'mew-summary-form-list', 
+(defun mew-decide-summary-form (folder)
+  (mew-folder-spec folder
+		   mew-summary-form-list
+		   mew-summary-form-list-string-type
+		   mew-summary-form-list-list-type))
+
+(defun mew-get-summary-form (folder)
+  "Get summary-form from 'mew-summary-form-list',
 'mew-summary-form-list-string-type, and 'mew-summary-form-list-list-type'.
-'mew-summary-form-header' is prepended. If COLUMN is non-nil, the number
-of thread indent position is returned."
-  (let (ret form col)
-    (setq ret (mew-folder-spec folder
-			       mew-summary-form-list
-			       mew-summary-form-list-string-type
-			       mew-summary-form-list-list-type))
-    (if ret
-	(mew-set '(form col) ret)
-      (setq form mew-summary-form))
-    (setq form (append mew-summary-form-header form))
-    (if column
-	(if (numberp col) col (mew-thread-column form))
-      form)))
+'mew-summary-form-header' is prepended. "
+  (let* ((form-col (mew-decide-summary-form folder))
+	 (form (or (nth 0 form-col) mew-summary-form)))
+    (append mew-summary-form-header form)))
+
+(defun mew-get-summary-column (folder)
+  (let ((form-col (mew-decide-summary-form folder)))
+    (or (nth 1 form-col)
+	(mew-thread-column (mew-get-summary-form folder))
+	mew-thread-column)))
 
 (defun mew-thread-column (form)
-  (let ((col 0) ret ent)
+  (let ((col 0))
     (catch 'loop
-      (while form
-	(setq ent (car form))
-	(setq form (cdr form))
+      (dolist (ent form)
 	(cond
 	 ((consp ent)
 	  (setq col (+ col (abs (car ent)))))
 	 ((stringp ent)
 	  (setq col (+ col (string-width ent))))
 	 ((eq ent t)
-	  (throw 'loop (setq ret col)))
+	  (throw 'loop col))
 	 (t
-	  (setq col (1+ col))))))
-    (or ret mew-thread-column)))
+	  (setq col (1+ col))))))))
 
 (defun mew-get-unread-mark (folder)
   (car (mew-folder-spec folder
@@ -299,22 +306,25 @@ of thread indent position is returned."
 ;;; The engine function to call mew-summary-form-*
 ;;;
 
+(defvar mew-inherit-total nil)
+(defvar mew-inherit-width nil)
+
 (defun mew-scan-get-piece (spec)
   (let (func width str rightp nopad)
     (if (stringp spec)
 	(progn
-	  (setq TOTAL (+ TOTAL (string-width spec)))
+	  (setq mew-inherit-total (+ mew-inherit-total (string-width spec)))
 	  spec)
       (if (symbolp spec)
 	  (setq width 1 func spec)
 	(mew-set '(width func) spec))
       (when (and (integerp width) (symbolp func))
 	(when (= width 0)
-	  (setq width (- WIDTH TOTAL 1))
+	  (setq width (- mew-inherit-width mew-inherit-total 1))
 	  (unless mew-use-spc-padding
 	    (setq nopad t)))
 	(if (< width 0) (setq width (abs width) rightp t))
-	(setq TOTAL (+ TOTAL width))
+	(setq mew-inherit-total (+ mew-inherit-total width))
 	(setq func (intern-soft
 		    (concat mew-summary-form-func-prefix (symbol-name func))))
 	(when (fboundp func)
@@ -322,12 +332,18 @@ of thread indent position is returned."
 	  (if rightp
 	      (if (<= (string-width str) width)
 		  (format (format "%%%ds" width) str)
-		(setq TOTAL (+ (- TOTAL width) (string-width str)))
+		(setq mew-inherit-total (+ (- mew-inherit-total width) (string-width str)))
 		str) ;; width may exceed.
 	    (mew-substring str width nil nopad)))))))
 
-(defun mew-scan-get-line (mew-vec WIDTH)
-  (let* ((TOTAL 0) (fld "")
+(defun mew-sumsym-encode-folder (fld)
+  (mew-replace-character fld ?  ?\t))
+
+(defun mew-sumsym-decode-folder (fld)
+  (mew-replace-character fld ?\t ? ))
+
+(defun mew-scan-get-line (mew-vec mew-inherit-width)
+  (let* ((mew-inherit-total 0) (fld "")
 	 (line (mapconcat 'mew-scan-get-piece (mew-sinfo-get-summary-form) ""))
 	 par-id my-id msg ld uid siz irt-list)
     (setq my-id (or (mew-idstr-get-first-id (MEW-ID)) ""))
@@ -337,7 +353,7 @@ of thread indent position is returned."
     ;; "thread" of conversation.
     ;;
     ;; However, even if the References field exists, it may not contain
-    ;; a parent's ID. So, if the In-Reply-To field contain one ID, 
+    ;; a parent's ID. So, if the In-Reply-To field contain one ID,
     ;; we use it for thread.
     ;;
     ;; (1) The In-Reply-To contains one ID, use it.
@@ -352,10 +368,11 @@ of thread indent position is returned."
 			 (car irt-list)
 			 ""))))
     (when (mew-virtual-p)
-      (setq fld (or (cdr (assoc (mew-scan-get-folder mew-vec)
-				(mew-vinfo-get-lra)))
-		    ;; Spotlight
-		    (MEW-FLD)))) ;; xxx
+      (setq fld (mew-sumsym-encode-folder
+		 (or (cdr (assoc (mew-scan-get-folder mew-vec)
+				 (mew-vinfo-get-lra)))
+		     ;; Spotlight
+		     (MEW-FLD))))) ;; xxx
     (setq msg (mew-scan-get-message mew-vec))
     (setq uid (or (mew-scan-uid-uid (MEW-UID)) ""))
     (setq siz (or (mew-scan-uid-size (MEW-UID)) ""))
@@ -365,8 +382,7 @@ of thread indent position is returned."
 ;; See also mew-summary-cook-region
 (defun mew-scan-insert-line (folder vec width lmsg &optional mark-or-dst)
   (when (get-buffer folder)
-    (save-excursion
-      (set-buffer folder)
+    (with-current-buffer folder
       (let* ((line (mew-scan-get-line vec width))
 	     (opos (point))
 	     (omax (point-max))
@@ -382,7 +398,6 @@ of thread indent position is returned."
 	     ;; To avoid inserting a line AFTER the cursor underline,
 	     ;; keep this line and make it invisible.
 	     (put-text-property beg (point) 'invisible t)
-	     (mew-front-nonsticky beg (1+ beg)) ;; for XEmacs
 	     (forward-line -1)))
 	 (setq beg (point))
 	 ;; To "insert" just after mew-marker-decode-syntax-end.
@@ -390,14 +405,13 @@ of thread indent position is returned."
 	 (setq med (point))
 	 (insert (cdr line))
 	 (goto-char beg)
-	 (mew-front-nonsticky beg med) ;; for XEmacs
 	 (cond
 	  ((stringp mark-or-dst) ;; xxx
 	   (setq msg (mew-scan-get-message vec))
 	   (mew-refile-reset msg)
 	   (mew-refile-set msg (mew-split mark-or-dst ?,))
 	   (mew-summary-refile-log folder mark-or-dst)
-	   (setq med (+ med (mew-summary-refile-override-body mark-or-dst)))
+	   (setq med (+ med (mew-summary-refile-override-body mark-or-dst 'force)))
 	   (mew-mark-put mew-mark-refile))
 	  ((mew-characterp mark-or-dst) ;; mew-inbox-action-alist
 	   (mew-mark-put mark-or-dst))
@@ -474,11 +488,9 @@ of thread indent position is returned."
 
 (defun mew-scan-inbox-action (mew-vec case)
   (let ((alist (mew-inbox-action-alist case))
-	ent key act val val-func ret mark-or-dst regex-list)
+	key val val-func ret mark-or-dst regex-list)
     (catch 'loop
-      (while alist
-	(setq ent (car alist))
-	(setq alist (cdr alist))
+      (dolist (ent alist)
 	(setq key (car ent))
 	(setq val-func (mew-scan-field-to-func key))
 	(if (and val-func (functionp val-func))
@@ -486,9 +498,7 @@ of thread indent position is returned."
 	  (setq val nil))
 	(when val
 	  (setq ent (cdr ent))
-	  (while ent
-	    (setq act (car ent))
-	    (setq ent (cdr ent))
+	  (dolist (act ent)
 	    (if (symbolp act)
 		(when (fboundp act)
 		  (setq ret (funcall act val))
@@ -496,10 +506,9 @@ of thread indent position is returned."
 	      (when (listp act)
 		(setq mark-or-dst (car act))
 		(setq regex-list (cdr act))
-		(while regex-list
-		  (if (string-match (car regex-list) val)
-		      (throw 'loop (setq ret mark-or-dst)))
-		  (setq regex-list (cdr regex-list)))))))))
+		(dolist (rl regex-list)
+		  (if (string-match rl val)
+		      (throw 'loop (setq ret mark-or-dst))))))))))
     ret))
 
 (defvar mew-regex-ignore-scan-body-list
@@ -507,13 +516,13 @@ of thread indent position is returned."
     "^[ \t]*[-a-zA-Z0-9]+: "
     "^[ \t]*[>:|#;/_}]"
     "^[ \t]*\\w+\\(['._-]+\\w+\\)*>"
-    "^[ \t]*[[</(.]+ *snip"
+    "^[ \t]*[[</(.-]+ *\\(snip\\|\\.\\.\\)"
     "^   "
     "^--"
     "^- --"
     "^=2D"
-    "^.*\\(:\\|;\\|/\\)[ \t]*$"
-    "^.*\\(wrote\\|writes?\\|said\\|says?\\)[^.!\n]?[ \t]*$"
+    "^.\\{1,100\\}\\(:\\|;\\|/\\)[ \t]*$"
+    "^.\\{1,100\\}\\(wrote\\|writes?\\|said\\|says?\\)[^.!\n]?[ \t]*$"
     "^[ \t]*\\(On\\|At\\) .*[^.! \t\n][ \t]*$"
     "^[ \t]*In \\(message\\|article\\|mail\\|news\\|<\\|\"\\|\\[\\|(\\)"))
 
@@ -545,7 +554,7 @@ of thread indent position is returned."
 	  (setq boundary (mew-match-string 1 ctr))
 	  (setq boundary (concat "^--" (regexp-quote boundary)))
 	  (catch 'loop
-	    (while (< i I) 
+	    (while (< i I)
 	      (if (looking-at boundary) (throw 'loop (setq found t)))
 	      (forward-line)
 	      (setq i (1+ i))))
@@ -565,21 +574,21 @@ of thread indent position is returned."
 	(if (and cte (mew-case-equal cte mew-b64)) (throw 'break nil))
 	(when (string-match "^Text/Plain" ctr)
 	  (when (string-match "charset=\"?\\([^\"\n\t;]+\\)\"?" ctr)
-	    (setq charset (mew-match-string 1 ctr))) 
+	    (setq charset (mew-match-string 1 ctr)))
 	  ;; xxx quoted-printable. not enough DB in mew-mule3.el.
 	  (setq textp t)
 	  (setq cs (mew-charset-to-cs charset))
 	  (if (null cs) (setq cs mew-cs-autoconv)))))) ;; end of 'break
+    (set-buffer-multibyte nil)
     (when (and textp (mew-coding-system-p cs))
       (setq i 0)
       (while (and (not (eobp)) (< i I) (< j J))
 	(setq regex mew-regex-ignore-scan-body-list)
 	(setq skip nil)
 	(catch 'matched
-	  (while regex
-	    (if (looking-at (car regex))
-		(throw 'matched (setq skip t)))
-	    (setq regex (cdr regex))))
+	  (dolist (re regex)
+	    (if (looking-at re)
+		(throw 'matched (setq skip t)))))
 	(if skip
 	    (forward-line)
 	  (when (looking-at "^[ \t]+")
@@ -589,7 +598,11 @@ of thread indent position is returned."
 	  (setq body (concat body (mew-buffer-substring beg (1- (point))) " "))
 	  (setq j (1+ j)))
 	(setq i (1+ i)))
-      (setq body (mew-cs-decode-string (mew-replace-white-space body) cs))
+      (set-buffer-multibyte t)
+      (setq body (mew-replace-white-space body))
+      (setq body (condition-case nil
+		     (mew-cs-decode-string body cs)
+		   (error body)))
       (aset mew-vec (1- (length mew-vec)) body))))
 
 (defun mew-scan-width ()
@@ -603,13 +616,13 @@ of thread indent position is returned."
 ;;; X-Mew-Uidl:
 ;;;
 
-(defsubst mew-scan-uid-uid (uid)
+(defun mew-scan-uid-uid (uid)
   (nth 0 (mew-split uid mew-sp)))
 
-(defsubst mew-scan-uid-size (uid)
+(defun mew-scan-uid-size (uid)
   (nth 1 (mew-split uid mew-sp)))
 
-(defsubst mew-scan-uid-case (uid)
+(defun mew-scan-uid-case (uid)
   (nth 2 (mew-split uid mew-sp)))
 
 (defun mew-header-insert-xmu (uid siz truncated &optional case)
@@ -724,7 +737,7 @@ non-nil, only headers of messages are cached. If executed with
     (if (> (nth 1 t1) (nth 1 t2)) t nil)) ;; nil if equal
    (t nil)))
 
-(defsubst mew-summary-folder-dir-newp ()
+(defun mew-summary-folder-dir-newp ()
   (let* ((folder (mew-summary-folder-name 'ext))
 	 (dir (file-chase-links (mew-expand-folder folder)))
 	 (mfile (expand-file-name mew-summary-touch-file dir))
@@ -737,7 +750,7 @@ non-nil, only headers of messages are cached. If executed with
 	t
       (mew-compare-times t1 t2))))
 
-(defsubst mew-summary-folder-cache-newp ()
+(defun mew-summary-folder-cache-newp ()
   (let* ((folder (mew-summary-folder-name 'ext))
 	 (cache (mew-expand-file folder mew-summary-cache-file))
 	 (t1 (mew-file-get-time cache))
@@ -772,9 +785,8 @@ non-nil, only headers of messages are cached. If executed with
 	       (mew-summary-folder-cache-newp))
       (mew-elet
        (mew-erase-buffer)
-       (mew-frwlet
-	mew-cs-m17n mew-cs-dummy
-	(mew-insert-file-contents cache))
+       (mew-frwlet mew-cs-m17n mew-cs-dummy
+	 (mew-insert-file-contents cache))
        (mew-sinfo-set-cache-time (mew-file-get-time cache))
        (if (= (point-max) 1)
 	   (setq mew-summary-buffer-raw nil)
@@ -803,16 +815,14 @@ non-nil, only headers of messages are cached. If executed with
 	      (with-temp-buffer
 		(mew-insert-buffer-substring cbuf min beg)
 		(mew-insert-buffer-substring cbuf end max)
-		(mew-frwlet
-		 mew-cs-dummy mew-cs-m17n
-		 (write-region (point-min) (point-max) cache nil 'no-msg))))
+		(mew-frwlet mew-cs-dummy mew-cs-m17n
+		  (write-region (point-min) (point-max) cache nil 'no-msg))))
 	  ;; (write-region 1 1 ...) does not update the file timestamp
 	  ;; but does the directory timestamp. So, we need to delete
 	  ;; the file to update the file timestamp.
 	  (if (= (point-min) (point-max)) (mew-delete-file cache))
-	  (mew-frwlet
-	   mew-cs-dummy mew-cs-m17n
-	   (write-region (point-min) (point-max) cache nil 'no-msg))
+	  (mew-frwlet mew-cs-dummy mew-cs-m17n
+	    (write-region (point-min) (point-max) cache nil 'no-msg))
 	  (mew-set-file-modes cache))
 	(mew-summary-set-count-line)
 	(mew-sinfo-set-cache-time (mew-file-get-time cache))
@@ -823,8 +833,7 @@ non-nil, only headers of messages are cached. If executed with
 (defun mew-summary-folder-cache-clean (folder)
   "Erase Summary mode then remove and touch the cache file."
   (if (get-buffer folder)
-      (save-excursion
-	(set-buffer folder)
+      (with-current-buffer folder
 	(mew-erase-buffer)
 	(set-buffer-modified-p nil)))
   (let ((cfile (mew-expand-file folder mew-summary-cache-file)))
@@ -833,15 +842,21 @@ non-nil, only headers of messages are cached. If executed with
 
 (provide 'mew-scan)
 
+(defvar mew-compiling nil)
+(eval-when-compile
+  (when mew-compiling
+    (require 'mew-varsx)
+    (mew-scan-setup)))
+
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2006 Mew developing team.
+;; Copyright (C) 1996-2012 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -850,7 +865,7 @@ non-nil, only headers of messages are cached. If executed with
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
